import { lazy, Suspense, useState, useEffect } from 'react';
import { Routes, Route } from 'react-router-dom';
import { Header } from './components/Header';
import { useLanguage } from './contexts/LanguageContext';
import { ArrowUp } from 'lucide-react';

// Group lazy-loaded components by feature
const components = {
  safety: {
    HealthSafety: lazy(() => import('./components/HealthSafety').then(m => ({ default: m.HealthSafety }))),
    SecurityAdvisory: lazy(() => import('./components/SecurityAdvisory').then(m => ({ default: m.SecurityAdvisory }))),
    TransportAdvisory: lazy(() => import('./components/TransportAdvisory').then(m => ({ default: m.TransportAdvisory }))),
    WeatherAlerts: lazy(() => import('./components/WeatherAlerts').then(m => ({ default: m.WeatherAlerts })))
  },
  search: {
    RealEstateSearch: lazy(() => import('./components/RealEstateSearch').then(m => ({ default: m.RealEstateSearch }))),
    FlightSearch: lazy(() => import('./components/FlightSearch').then(m => ({ default: m.FlightSearch }))),
    RestaurantSearch: lazy(() => import('./components/RestaurantSearch').then(m => ({ default: m.RestaurantSearch }))),
    CarRentalSearch: lazy(() => import('./components/CarRentalSearch').then(m => ({ default: m.CarRentalSearch }))),
    LocalStaySearch: lazy(() => import('./components/LocalStaySearch').then(m => ({ default: m.LocalStaySearch }))),
    EventSearch: lazy(() => import('./components/EventSearch').then(m => ({ default: m.EventSearch })))
  },
  guides: {
    TransportGuide: lazy(() => import('./components/TransportGuide').then(m => ({ default: m.TransportGuide }))),
    TravelRequirements: lazy(() => import('./components/TravelRequirements').then(m => ({ default: m.TravelRequirements }))),
    LanguageGuide: lazy(() => import('./components/LanguageGuide').then(m => ({ default: m.LanguageGuide }))),
    CurrencyGuide: lazy(() => import('./components/CurrencyGuide').then(m => ({ default: m.CurrencyGuide })))
  },
  features: {
    LocalTourism: lazy(() => import('./components/LocalTourism').then(m => ({ default: m.LocalTourism }))),
    NationalParks: lazy(() => import('./components/NationalParks').then(m => ({ default: m.NationalParks }))),
    SeasonalEvents: lazy(() => import('./components/SeasonalEvents').then(m => ({ default: m.SeasonalEvents }))),
    LocalExperiences: lazy(() => import('./components/LocalExperiences').then(m => ({ default: m.LocalExperiences })))
  },
  info: {
    WeatherWidget: lazy(() => import('./components/WeatherWidget').then(m => ({ default: m.WeatherWidget }))),
    EmergencyInfo: lazy(() => import('./components/EmergencyInfo').then(m => ({ default: m.EmergencyInfo }))),
    TourismStats: lazy(() => import('./components/TourismStats').then(m => ({ default: m.TourismStats }))),
    ExpoCenters: lazy(() => import('./components/ExpoCenters').then(m => ({ default: m.ExpoCenters })))
  },
  tools: {
    TravelTools: lazy(() => import('./components/TravelTools').then(m => ({ default: m.TravelTools }))),
    CurrencyConverter: lazy(() => import('./components/CurrencyConverter').then(m => ({ default: m.CurrencyConverter }))),
    TimeZones: lazy(() => import('./components/TimeZones').then(m => ({ default: m.TimeZones }))),
    InteractiveMap: lazy(() => import('./components/InteractiveMap').then(m => ({ default: m.InteractiveMap }))),
    TravelPlanner: lazy(() => import('./components/TravelPlanner').then(m => ({ default: m.TravelPlanner })))
  }
};

// Lazy load pages
const Home = lazy(() => import('./pages/Home').then(m => ({ default: m.Home })));
const LiveWebcams = lazy(() => import('./pages/LiveWebcams').then(m => ({ default: m.LiveWebcams })));
const Provinces = lazy(() => import('./pages/Provinces').then(m => ({ default: m.Provinces })));
const WineRegions = lazy(() => import('./pages/WineRegions').then(m => ({ default: m.WineRegions })));
const BusinessTravel = lazy(() => import('./pages/BusinessTravel').then(m => ({ default: m.BusinessTravel })));
const MountainTowns = lazy(() => import('./pages/MountainTowns').then(m => ({ default: m.MountainTowns })));
const MaritimeCities = lazy(() => import('./pages/MaritimeCities').then(m => ({ default: m.MaritimeCities })));
const HistoricSites = lazy(() => import('./pages/HistoricSites').then(m => ({ default: m.HistoricSites })));
const USToCanada = lazy(() => import('./pages/USToCanada').then(m => ({ default: m.USToCanada })));
const TourismData = lazy(() => import('./pages/TourismData').then(m => ({ default: m.TourismData })));
const WeatherGuide = lazy(() => import('./pages/WeatherGuide').then(m => ({ default: m.WeatherGuide })));

// SEO Helper Components
const PageMetadata = ({ title, description }: { title: string; description: string }): null => {
  useEffect(() => {
    document.title = `Tourism Canada | ${title}`;
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', description);
    }
  }, [title, description]);
  return null;
};

function App() {
  const { t } = useLanguage();
  const [showBackToTop, setShowBackToTop] = useState(false);

  useEffect(() => {
    const handleScroll = () => {
      setShowBackToTop(window.scrollY > 500);
    };

    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const scrollToTop = () => {
    window.scrollTo({ top: 0, behavior: 'smooth' });
  };

  return (
    <div className="min-h-screen bg-gray-50">
      <PageMetadata 
        title="Official Guide to Canadian Travel, Cities & Experiences"
        description="Tourism Canada offers the ultimate guide to exploring Canada's majestic national parks, vibrant cities, and unique cultural experiences. Plan your Canadian adventure with our official travel resources."
      />
      <Header />
      <Suspense fallback={
        <div className="min-h-screen flex items-center justify-center">
          <div className="animate-spin rounded-full h-32 w-32 border-t-2 border-b-2 border-red-600"></div>
        </div>
      }>
        <Routes>
          <Route path="/" element={<Home />} />
          <Route path="/provinces" element={<Provinces />} />
          <Route path="/live-webcams" element={<LiveWebcams />} />
          <Route path="/wine-regions" element={<WineRegions />} />
          <Route path="/business-travel" element={<BusinessTravel />} />
          <Route path="/mountain-towns" element={<MountainTowns />} />
          <Route path="/maritime-cities" element={<MaritimeCities />} />
          <Route path="/historic-sites" element={<HistoricSites />} />
          <Route path="/us-to-canada" element={<USToCanada />} />
          <Route path="/tourism-data" element={<TourismData />} />
          <Route path="/weather-guide" element={<WeatherGuide />} />
          <Route path="/weather-alerts" element={<components.safety.WeatherAlerts />} />
        </Routes>
      </Suspense>

      <footer className="bg-gray-900 text-white py-8 px-4 mt-16">
        <div className="max-w-7xl mx-auto text-center">
          <p className="mb-2">
            © {new Date().getFullYear()} Tourism Canada. {t('footer.rights')}
          </p>
          <p className="text-gray-400">
            {t('footer.tagline')}
          </p>
        </div>
      </footer>
      
      <button
        onClick={scrollToTop}
        className={`fixed bottom-8 right-8 p-4 bg-red-600 text-white rounded-full shadow-lg hover:bg-red-700 transition-all back-to-top ${
          showBackToTop ? 'visible' : ''
        }`}
        aria-label="Back to top"
      >
        <ArrowUp className="w-6 h-6" />
      </button>
    </div>
  );
}

export default App